month

# XMLRésuméLibrary: User Guide

misc | Element Reference | name

## Name

month — A month name

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `month` element contains the name of a month, such as “March” (English), “marzo” (Spanish), or “mars” (French).

### Parents

`month` may be contained in these elements: `date`, `pubDate`

## See Also

`dayOfMonth`, `year`.

## Examples

    <month>April</month>

misc | Element Reference | name